CameraToCamera

Struct CameraToCamera 

pub struct CameraToCamera(pub IsometryMatrix3<f64>);
This contains a relative pose, which is a pose that transforms the CameraPoint of one image into the corresponding CameraPoint of another image. This transforms the point from the camera space of camera A to camera B.

Camera space for a given camera is defined as thus:

  • Origin is the optical center
  • Positive z axis is forwards
  • Positive y axis is up
  • Positive x axis is right

Note that this is a left-handed coordinate space.

Tuple Fields

0: IsometryMatrix3<f64>